# Changelog

All notable changes to this project will be documented in this file.

## [0.1.1] - 2022/12/2

### Changed

- Rename ``Rate`` class to ``RateLimiter``

## [0.1.0] - 2022/12/2

- Loop rate limiter based on ``time.perf_counter``
